PCB Environment: RewardFunction Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
RewardFunction Class Referenceabstract
Inheritance diagram for RewardFunction:

## Public Member Functions
virtual void | setContext (const PCBoard &)
virtual Reward | operator() (const Connection &, RouterResult *=0) const =0
virtual Reward | operator() (const std::vector< Connection * > &, RouterResult *=0) const =0
virtual Reward | operator() (int unrouted) const =0

## Static Public Member Functions
static RewardFunction * | create (PyObject *)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Reward.hpp